#!/usr/bin/perl
#getDiscProfileList.pl
# Author - Seenu Mathew - seenu.mathew@ca.com
# Prerequisites: tested with perl 5.18
#	typically, REST::Client and XML::Simple modules must be installed (cpan)
#  
# DISCLAIMER
# This script is provided AS IS and no warranties are provided or made.  
# For more information refer to http://www.ca.com/us/legal/terms-for-user-sites.aspx
=pod
Perl script to list all the discovery profiles, status, create time and ip address list in a csv file.

This script can be run from any machine which has Strawberry perl and a valid connection to Data Aggregator using rest client.

1.	Issue a HTTP GET to http://imda1rh65:8581/rest/discoveryprofiles
2.	Print out into a csv file, all files required fields filtering out from the XML received from GET
=cut

use strict;
use warnings;
use Getopt::Std;
use REST::Client;
use XML::Simple;

$| = 1;

sub main() {

	my %opt;
	getopts( 'h:p:f:help', \%opt );

	my $filename = $opt{f};
	my $port     = $opt{p};
	my $hostname = $opt{h};
		
	if(!checkusage($hostname,$port,$filename)) {
		usage();
	} 
	
	else {
	createXmlFile( $hostname, $port, $filename );
	}	
}

sub checkusage(){
	
	my $filename = shift;
	my $hostname = shift;
	my $port = shift;
	
	unless(defined($filename) and defined($hostname) and defined($port)) {
		return 0;
	}
}

sub usage() {

	my $help = <<USAGE;
	Usage of getDiscProfileList.pl is as follows
	
	-h <hostname or ip address of CA Data Aggregator>
	-p <port number>
	-f <filename>
	-help <to display this help message>
	
Example: perl getDiscProfileList.pl -h DataAggregatorHostname -p 8581 -f profiles
	The above command will create a csv file called profiles.csv with the list of Names, Createtimes, ID etc..
										
USAGE

	die $help;

}

sub createXmlFile() {

	my $hostname = shift;
	my $port     = shift;
	my $filename = shift;
	my $url      = $hostname . ":" . $port . '/rest';

	my $client = REST::Client->new( host => $url );
	$client->GET('/discoveryprofiles');

	open( XML, "> " . $filename . ".xml" )
	  or die "error when creating outputfile '$filename'.xml: $!\n";
	print XML $client->responseContent() . "\n";
	close(XML);

	my $xml = new XML::Simple;
	my $data = $xml->XMLin( $filename . ".xml",ForceArray => 1);

	#print Dumper($data);

	open( my $fh, '>', $filename . ".csv" )
	  or die "Could not open file '$filename' .csv $!";
	print $fh "ID,Name,CreateTime,IcmpDiscoveryEnabled,RunStatus,IPList\n";

	#Getting into the XML file to the Discovery profile section
	foreach my $discProfile ( @{ $data->{DiscoveryProfile} } ) {
		
		my $item = $discProfile->{Item};
		print $fh $discProfile->{ID}->[0] . ",";
		my $icmp = $discProfile->{IcmpDiscoveryEnabled}->[0];				
		my $run = $discProfile->{RunStatus}->[0];
		#As Item is an arry, We have to traverse through the array and print. 
		#There is only one name and create time therefore [0] is being used
		foreach my $attr (@{$item}){
		#print Dumper($attr);
		print $fh $attr->{Name}->[0] . ",";
		print $fh $attr->{CreateTime}->[0] . ",";
		print $fh $icmp . ",";
		print $fh $run . ",";
		my $ipListList = $discProfile->{IPListList};
		#IPListList is a hash, therefore we are traversing through the hash 
		foreach my $ipList (@$ipListList){
								
				#print Dumper($ipList->{IPList});
				
				my $ip = $ipList->{IPList};
				# Traversing through the array of ip's and printing each of them.				
				for (@{$ip}){
					print $fh $_ . " ";
				}
		}
		
		print $fh "\n";

		}
	}
	close($fh);
	
}

main();